%define _unpackaged_files_terminate_build 1
%define oname x42-plugins

Name: lv2-%oname
Version: 20230706
Release: %mkrel 2
Summary: Collection LV2 plugins x42

License: GPL2 and  GPL3
Group: Sound

# https://x42-plugins.com/x42/ is more about binary builds
Url: https://github.com/x42/x42-plugins

# This package uses tarball from http://gareus.org/misc/x42-plugins.php
Source:		http://gareus.org/misc/x42-plugins/%oname-%version.tar.xz
Source1:	x42.png
Source2:	x42-plugins.directory
Source3:	x42-plugins.menu

BuildRequires: pkgconfig(libxdg-basedir) xdg-utils
BuildRequires: gcc-c++
BuildRequires: zita-convolver-devel

# git grep -Eo -e '(--cflags|--exists|--libs)( [-+0-9a-z]+)+'  | tr ' ' '\n' | grep -v -e '--' | sort -u
BuildRequires: make
BuildRequires:  gcc-c++
BuildRequires:  lv2-devel >= 1.8.1
BuildRequires:  zita-convolver-devel >= 3.1.0
BuildRequires:  jackit-devel
BuildRequires:  libltc-devel
BuildRequires:  libsndfile-devel
BuildRequires:  libsamplerate-devel
BuildRequires:  fftw3-devel
BuildRequires:  pango-devel
BuildRequires:  cairo-devel
BuildRequires:  glib2-devel
BuildRequires:  pkgconfig(glu)
BuildRequires:  pkgconfig(ftgl)
BuildRequires:  ftgl-devel
BuildRequires:  fonts-ttf-dejavu
BuildRequires:  fonts-ttf-dejavu-lgc
#BuildRequires:  gnu-free-sans-fonts
#BuildRequires:  gnu-free-serif-fonts
#BuildRequires:  gnu-free-mono-fonts
BuildRequires:  mesa-devel
Requires:       lv2 >= 1.8.1
#Requires:       gnu-free-sans-fonts
#Requires:       gnu-free-serif-fonts
#Requires:       gnu-free-mono-fonts


%description
A collection of x42 lv2 plugins including stereo balance,
midi filter, delay, convolver, fader, parametric equalizer,
auto-tune, awesome meters collection and others.

%prep
%setup -q -n %oname-%version


%build

xnames="darc dpl fat1 fil4 matrixmixer8x8 meter mixtri scope spectr stepseq tuna"

comments=(
    ["darc"]="A general purpose audio signal compressor"
    ["dpl"]="Look-ahead digital peak limiter intended but not limited to the final step of mastering or mixing"
    ["fat1"]="Auto-tuner based on Fons Adriaensen's zita-at1"
    ["fil4"]="4 band parametric equalizer with additional low+high shelf filters, Low and High-pass"
    ["matrixmixer8x8"]="Matrix Mixer 8x8"
    ["mixtri"]="Matrix mixer and trigger processor"
    ["scope"]="Simple audio oscilloscope with variable time scale, triggering, cursors and numeric readout"
    ["spectr"]="Spectrum Analyzer"
    ["stepseq"]="Simple step sequencer for moddevices.com"
)

generic=(
	["darc"]="Dynamic Audio Range Compressor"
    ["dpl"]="Peak Limiter"
    ["fat1"]="Auto Tune"
    ["fil4"]="Parametric Equalizer"
    ["matrixmixer8x8"]="Matrix Mixer"
    ["mixtri"]="Mixer'n'Trigger"
    ["scope"]="Oscilloscope"
    ["spectr"]="Spectrum Analyzer"
    ["stepseq"]="Step Sequencer"
)

meter_types=(
	[0]='EBU R128 Meter'
    [1]='K20/RMS Meter (Stereo)'
    [2]='K14/RMS Meter (Stereo)'
    [3]='K12/RMS Meter (Stereo)'
    [4]='BBC Meter (Stereo)'
    [5]='BBC M-6'
    [6]='DIN Meter (Stereo)'
    [7]='EBU Meter (Stereo)'
    [8]='Nordic Meter (Stereo)'
    [9]='VU Meter (Stereo)'
    [10]='True-Peak and RMS Meter (Stereo)'
    [11]='DR-14 - Crest Factor Loudness Range Meter'
    [12]='Stereo Phase-Correlation Meter'
    [13]='Goniometer'
    [14]='Phase/Frequency Wheel'
    [15]='1/3 Octave Spectrum Analyzer'
    [16]='Stereo/Frequency Scope'
    [17]='Signal Distribution Histogram'
    [18]='Bit Meter'
    [19]='Surround Level 8'
)

tuna_types=(
[0]='Instrument Tuner'
[1]='Instrument Tuner (Spectrum)'
)

# XDG desktop files

for name in $xnames; do
case $name in
	meter)
	for type in {0..19}; do
%__cat <<EOF > %_builddir/%oname-%version/com.x42_plugins.x42_meter_${type}.desktop
[Desktop Entry]
Version=1.0
Type=Application
Name=x42-meter ${meter_types[$type]}
Comment=${meter_types[$type]}
Exec=x42-meter $type
Icon=x42-meter
GenericName=Audio Meter
NotShowIn=GNOME;XFCE;KDE;MATE;PLASMA;
EOF
	done ;;
	tuna)
	for type in {0,1}; do
%__cat <<EOF > %_builddir/%oname-%version/com.x42_plugins.x42_${name}_${type}.desktop
[Desktop Entry]
Version=1.0
Type=Application
Name=x42-${name} ${tuna_types[$type]}
Comment=${tuna_types[$type]}
Exec=x42-${name} $type
Icon=x42-${name}
GenericName=Music Instrument Tuner
NotShowIn=GNOME;XFCE;KDE;MATE;PLASMA;
EOF
	done ;;
	*)
%__cat <<EOF > %_builddir/%oname-%version/com.x42_plugins.x42_${name}.desktop
[Desktop Entry]
Version=1.0
Type=Application
Name=x42-${name}
Comment=${comments[$name]}
Exec=x42-${name}
Icon=x42-${name}
GenericName=${generic[$name]}
NotShowIn=GNOME;XFCE;KDE;MATE;PLASMA;
EOF
	;;
esac

done
#########
#muchekuh

  # moving images to correct location so installation is not such a hassle later on
  mv -v fat1.lv2/img/x42{_,-}fat1.png
  mv -v fil4.lv2/img/x42{_,-}fil4.png
  mv -v mixtri.lv2/img/x42{_,-}mixtri.png
  mv -v meters.lv2/img/x42-meter{s,}.png
  mv -v matrixmixer.lv2/img/x42-matrixmixer{,8x8}.png


export FONTFILE=/usr/share/fonts/TTF/DejaVuSans-Bold.ttf
export STRIP=/bin/true

CFLAGS+=' -fcommon -fno-warn -fstrip %optflags'
#export PKG_CONFIG=pkgconf
#export OPTIMIZATIONS="%{optflags}"

%make_build LIBDIR=%{_libdir} LV2DIR=%{_libdir}/lv2 PREFIX=%{_prefix}

%make -C phaserotate.lv2/cli

%install
rm -rf %{buildroot}
%makeinstall_std LIBDIR=%{_libdir} LV2DIR=%{_libdir}/lv2 PREFIX=%{_prefix}

%make -C phaserotate.lv2/cli install DESTDIR=%{buildroot} PREFIX=%{_prefix}

mkdir -p %{buildroot}/usr/share/icons/hicolor/256x256/apps
%__install -m 644 %{S:1} %{buildroot}/usr/share/icons/hicolor/256x256/apps/

# xdg desktop integration
%__install -vDm 644 %_builddir/%oname-%version/*.desktop -t %{buildroot}/usr/share/applications/
# icons
pdirs=(
      ["darc"]="darc.lv2"
      ["dpl"]="dpl.lv2"
      ["fat1"]="fat1.lv2"
      ["fil4"]="fil4.lv2"
      ["matrixmixer8x8"]="matrixmixer.lv2"
      ["meter"]="meters.lv2"
      ["mixtri"]="mixtri.lv2"
      ["scope"]="sisco.lv2"
      ["spectr"]="spectra.lv2"
      ["stepseq"]="stepseq.lv2"
      ["tuna"]="tuna.lv2"
)

#for name in $xnames; do
for name in `ls -1 %_builddir/%oname-%version/*/img/*.png`; do
%__install -Dm 644 $name %{buildroot}/usr/share/icons/hicolor/256x256/apps/
done
# menu integration
%__install -Dm 644 %{S:3} %{buildroot}/etc/xdg/menus/applications-merged/x42-plugins.menu
mkdir -p %{buildroot}/usr/share/desktop-directories
%__install -Dm 644 %{S:2} %{buildroot}/usr/share/desktop-directories/
%__install -Dm 644 plugin.news %{buildroot}/usr/share/doc/%{name}/plugin.news

# not show in desktop-/applications-menu
sed -i s/"NotShowIn=GNOME;"/"NotShowIn=GNOME;KDE;XFCE;MATE;Plasma;"/g %{buildroot}%{_datadir}/applications/*.desktop


%post
/sbin/ldconfig
gtk-update-icon-cache /usr/share/icons/hicolor
%update_menus

%postun
/sbin/ldconfig
gtk-update-icon-cache /usr/share/icons/hicolor
%clean_menus

%files
%doc plugin.versions plugin.list plugin.news balance.lv2/COPYING balance.lv2/README.md
%{_sysconfdir}/xdg/menus/applications-merged/x42-plugins.menu
%{_libdir}/lv2/balance.lv2/
%{_libdir}/lv2/controlfilter.lv2/
##{_libdir}/lv2/convo.lv2/
%{_libdir}/lv2/darc.lv2/
%{_libdir}/lv2/dpl.lv2/
%{_libdir}/lv2/fat1.lv2/
%{_libdir}/lv2/fil4.lv2/
%{_libdir}/lv2/matrixmixer.lv2/
%{_libdir}/lv2/meters.lv2/
%{_libdir}/lv2/mididebug.lv2/
%{_libdir}/lv2/midifilter.lv2/
%{_libdir}/lv2/midigen.lv2/
%{_libdir}/lv2/midimap.lv2/
%{_libdir}/lv2/mixtri.lv2/
%{_libdir}/lv2/nodelay.lv2/
%{_libdir}/lv2/onsettrigger.lv2/
%{_libdir}/lv2/phaserotate.lv2/
%{_libdir}/lv2/sisco.lv2/
%{_libdir}/lv2/spectra.lv2/
%{_libdir}/lv2/stepseq_s8n8.lv2/
%{_libdir}/lv2/stereoroute.lv2/
%{_libdir}/lv2/testsignal.lv2/
%{_libdir}/lv2/tuna.lv2/
%{_libdir}/lv2/xfade.lv2/
%{_libdir}/lv2/zeroconvo.lv2/
%{_bindir}/phase-rotate
%{_bindir}/x42-darc
%{_bindir}/x42-dpl
%{_bindir}/x42-fat1
%{_bindir}/x42-fil4
%{_bindir}/x42-matrixmixer8x8
%{_bindir}/x42-meter
%{_bindir}/x42-mixtri
%{_bindir}/x42-phaserotate
%{_bindir}/x42-scope
%{_bindir}/x42-spectr
%{_bindir}/x42-stepseq
%{_bindir}/x42-tuna
%{_mandir}/man1/*
%{_datadir}/applications/com.x42_plugins.x42_darc.desktop
%{_datadir}/applications/com.x42_plugins.x42_dpl.desktop
%{_datadir}/applications/com.x42_plugins.x42_fat1.desktop
%{_datadir}/applications/com.x42_plugins.x42_fil4.desktop
%{_datadir}/applications/com.x42_plugins.x42_matrixmixer8x8.desktop
%{_datadir}/applications/com.x42_plugins.x42_meter_0.desktop
%{_datadir}/applications/com.x42_plugins.x42_meter_1.desktop
%{_datadir}/applications/com.x42_plugins.x42_meter_10.desktop
%{_datadir}/applications/com.x42_plugins.x42_meter_11.desktop
%{_datadir}/applications/com.x42_plugins.x42_meter_12.desktop
%{_datadir}/applications/com.x42_plugins.x42_meter_13.desktop
%{_datadir}/applications/com.x42_plugins.x42_meter_14.desktop
%{_datadir}/applications/com.x42_plugins.x42_meter_15.desktop
%{_datadir}/applications/com.x42_plugins.x42_meter_16.desktop
%{_datadir}/applications/com.x42_plugins.x42_meter_17.desktop
%{_datadir}/applications/com.x42_plugins.x42_meter_18.desktop
%{_datadir}/applications/com.x42_plugins.x42_meter_19.desktop
%{_datadir}/applications/com.x42_plugins.x42_meter_2.desktop
%{_datadir}/applications/com.x42_plugins.x42_meter_3.desktop
%{_datadir}/applications/com.x42_plugins.x42_meter_4.desktop
%{_datadir}/applications/com.x42_plugins.x42_meter_5.desktop
%{_datadir}/applications/com.x42_plugins.x42_meter_6.desktop
%{_datadir}/applications/com.x42_plugins.x42_meter_7.desktop
%{_datadir}/applications/com.x42_plugins.x42_meter_8.desktop
%{_datadir}/applications/com.x42_plugins.x42_meter_9.desktop
%{_datadir}/applications/com.x42_plugins.x42_mixtri.desktop
%{_datadir}/applications/com.x42_plugins.x42_scope.desktop
%{_datadir}/applications/com.x42_plugins.x42_spectr.desktop
%{_datadir}/applications/com.x42_plugins.x42_stepseq.desktop
%{_datadir}/applications/com.x42_plugins.x42_tuna_0.desktop
%{_datadir}/applications/com.x42_plugins.x42_tuna_1.desktop
%{_datadir}/desktop-directories/x42-plugins.directory
%{_datadir}/icons/hicolor/256x256/apps/darc.png
%{_datadir}/icons/hicolor/256x256/apps/dpl1.png
%{_datadir}/icons/hicolor/256x256/apps/fat1_v1.png
%{_datadir}/icons/hicolor/256x256/apps/fil4_scaling.png
%{_datadir}/icons/hicolor/256x256/apps/fil4_v2.png
%{_datadir}/icons/hicolor/256x256/apps/fil4_v6.png
%{_datadir}/icons/hicolor/256x256/apps/matrix16x20.png
%{_datadir}/icons/hicolor/256x256/apps/matrix_doc.png
%{_datadir}/icons/hicolor/256x256/apps/phase-rotated-sines-90deg.png
%{_datadir}/icons/hicolor/256x256/apps/spectr.png
%{_datadir}/icons/hicolor/256x256/apps/time-vs-phase-delay.png
%{_datadir}/icons/hicolor/256x256/apps/trigger_modes3.png
%{_datadir}/icons/hicolor/256x256/apps/x42-balance.png
##{_datadir}/icons/hicolor/256x256/apps/x42-convolv.png
%{_datadir}/icons/hicolor/256x256/apps/x42-ctrlfilter.png
%{_datadir}/icons/hicolor/256x256/apps/x42-darc.png
%{_datadir}/icons/hicolor/256x256/apps/x42-dpl.png
%{_datadir}/icons/hicolor/256x256/apps/x42-fat1.png
%{_datadir}/icons/hicolor/256x256/apps/x42-fil4.png
%{_datadir}/icons/hicolor/256x256/apps/x42-matrixmixer8x8.png
%{_datadir}/icons/hicolor/256x256/apps/x42-meter.png
%{_datadir}/icons/hicolor/256x256/apps/x42-mididebug.png
%{_datadir}/icons/hicolor/256x256/apps/x42-midifiltres.png
%{_datadir}/icons/hicolor/256x256/apps/x42-midigen.png
%{_datadir}/icons/hicolor/256x256/apps/x42-midimap.png
%{_datadir}/icons/hicolor/256x256/apps/x42-mixtri.png
%{_datadir}/icons/hicolor/256x256/apps/x42-nodelay.png
%{_datadir}/icons/hicolor/256x256/apps/x42-onsettrigger.png
%{_datadir}/icons/hicolor/256x256/apps/x42-phaserotate.png
%{_datadir}/icons/hicolor/256x256/apps/x42-scope.png
%{_datadir}/icons/hicolor/256x256/apps/x42-spectr.png
%{_datadir}/icons/hicolor/256x256/apps/x42-stepseq.png
%{_datadir}/icons/hicolor/256x256/apps/x42-stereoroute.png
%{_datadir}/icons/hicolor/256x256/apps/x42-testsignal.png
%{_datadir}/icons/hicolor/256x256/apps/x42-tuna.png
%{_datadir}/icons/hicolor/256x256/apps/x42-xfade.png
%{_datadir}/icons/hicolor/256x256/apps/x42-zconvolver.png
%{_datadir}/icons/hicolor/256x256/apps/x42.png


%changelog
* Sat Feb 10 2024 onkelho <oh.quait at gmail.com> - 20220107-2quait2024
- rebuild
- better fixing .desktop's
- add post ... 

* Thu Aug 10 2023 onkelho <oh.quait at gmail.com> - 20220107-1pclos2023
- newest source

* Thu Aug 10 2023 onkelho <oh.quait at gmail.com> - 20220107-2pclos2023
- rebuild
- fix desktop's

* Thu Feb 24 2022 onkelho <oh.quait at gmail.com> - 20220107-1pclos2022
- new package
